#Documentation https://pypi.org/project/googletrans/
#Installation pip install googletrans

from googletrans import Translator

def load_text_file(file_path):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()
            return True, content
    except Exception as e:
        print(f"Error loading the text file: {e}")
        return False, None

def detect_language(file_path):
    try:
        flag, content = load_text_file(file_path)
        if flag:
            print(content)
            
            translator = Translator() 
            language_detected = translator.detect(content)
            language = language_detected.lang 
            return True, language
        else:
            language = None
            return False, language
    
    except Exception as e:
        print(f"Error in detecting langauge: {e}")
        return False, None
    
file_path = "data/german.txt"

flag, language = detect_language(file_path)
if flag:
    print(language)




#Documentation https://github.com/detectlanguage/detectlanguage-python
#Installation pip install detectlanguage

import detectlanguage

def load_text_file(file_path):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()
            return True, content
    except Exception as e:
        print(f"Error loading the text file: {e}")
        return False, None

def detect_language(file_path):
    try:
        api_key = "cd0d7ee1c00134e594282fbb9fd12fdf" #Free

        flag, content = load_text_file(file_path)
        if flag:
            print(content)
        
            detectlanguage.configuration.api_key = api_key
            result = detectlanguage.detect(content)
            print(result)
            language_detected = result[0]['language']
            return True, language_detected
        else:
            return False, None
    
    except Exception as e:
        print(f"Error in detecting langauge: {e}")
        return False, None
    
file_path = "data/german.txt"
flag, language = detect_language(file_path)
if flag:
    print(language)




#Documentation https://pypi.org/project/deep-translator/
#Installationpip install deep-translator

import os 
from deep_translator import GoogleTranslator

PATH = os.get
def load_text_file(file_path):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()
            return True, content
    except Exception as e:
        print(f"Error loading the text file: {e}")
        return False, None

def translate_file(file_path):
    try:
        #target is language you want to translate your text into

        flag, content = load_text_file(file_path)
        if flag:
            print(content)
        translated_text = GoogleTranslator(source='auto', target='en').translate(content)
        return True, translated_text
    
    except Exception as e:
        print(f"Error in detecting langauge: {e}")
        return False, None
    
file_path = "data/german.txt"
flag, translated_content = translate_file(file_path)
if flag:
    print(translated_content)




#Documentation https://pypi.org/project/googletrans/
#Installation pip install googletrans

from googletrans import Translator

def load_text_file(file_path):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()
            return True, content
    except Exception as e:
        print(f"Error loading the text file: {e}")
        return False, None

def translate_file(file_path):
    try:

        flag, content = load_text_file(file_path)
        if flag:
            print(content)

            translator = Translator() 
            result = translator.translate(content, dest='en') 
            return True, result.text
        else:
            return False, None
    
    except Exception as e:
        print(f"Error in detecting langauge: {e}")
        return False, None
    
file_path = "data/german.txt"
flag, translated_content = translate_file(file_path)
if flag:
    print(translated_content)




import setuptools

setuptools.setup(
    name="easyLang",
    version="0.0.2",
    author="Fizahat",
    description="Language translations & detections module",
    packages=["easyLang", "easyLang.Language_detection", "easyLang.Language_translation"],
)